Documentation
¶
Index ¶
- Variables
- type BankingClient
- func (b *BankingClient) GetAccessToken() error
- func (b BankingClient) GetAccountBalance(accountId string) (api.Balance, error)
- func (b BankingClient) GetAccountTransactions(accountID string, fromDate, toDate string) (api.Transactions, error)
- func (b BankingClient) GetAccounts() (api.Accounts, error)
- func (b BankingClient) GetBeneficiaries() (api.Beneficiaries, error)
- func (b BankingClient) PayMultiple(accountID string, payments []api.PaymentMultiple) (api.MultiplePaymentResponse, error)
- func (b BankingClient) TransferMultiple(accountID string, transfers []api.TransferTo) (api.MultipleTransfersResponse, error)
Constants ¶
This section is empty.
Variables ¶
var APIurl string = "https://openapi.investec.com"
var IsDebug bool
Functions ¶
This section is empty.
Types ¶
type BankingClient ¶
type BankingClient struct {
UserCreds string
AccessToken string
// contains filtered or unexported fields
}
func NewBankingClient ¶
func NewBankingClient(key, secret, clientID string) BankingClient
func (*BankingClient) GetAccessToken ¶
func (b *BankingClient) GetAccessToken() error
GetAccessToken
func (BankingClient) GetAccountBalance ¶
func (b BankingClient) GetAccountBalance(accountId string) (api.Balance, error)
GetAccountBalance
func (BankingClient) GetAccountTransactions ¶
func (b BankingClient) GetAccountTransactions(accountID string, fromDate, toDate string) (api.Transactions, error)
GetAccountTransactions gets account transactions you can filter the result using the fromDate and toDate parameters and the dates need to follow ISO 8601 time format
func (BankingClient) GetAccounts ¶
func (b BankingClient) GetAccounts() (api.Accounts, error)
GetAccounts
func (BankingClient) GetBeneficiaries ¶
func (b BankingClient) GetBeneficiaries() (api.Beneficiaries, error)
GetBeneficiaries
func (BankingClient) PayMultiple ¶
func (b BankingClient) PayMultiple(accountID string, payments []api.PaymentMultiple) (api.MultiplePaymentResponse, error)
PayMultiple
func (BankingClient) TransferMultiple ¶
func (b BankingClient) TransferMultiple(accountID string, transfers []api.TransferTo) (api.MultipleTransfersResponse, error)
TransferMultiple
Click to show internal directories.
Click to hide internal directories.